@@ -8,15 +8,17 @@ register = template.Library()
 
 
 @register.simple_tag
-def mathjax_scripts():
+def mathjax_scripts(https=None):
     if not getattr(settings, 'MATHJAX_ENABLED', False):
         return ''
 
     mathjax_local_path = getattr(settings, 'MATHJAX_LOCAL_PATH', None)
     if mathjax_local_path:
         mathjax_js_url = static('%s/MathJax.js' % mathjax_local_path)
+    elif https:
+        mathjax_js_url = 'https://c328740.ssl.cf1.rackcdn.com/mathjax/latest/MathJax.js'
     else:
-        mathjax_js_url = '//cdn.mathjax.org/mathjax/latest/MathJax.js'
+        mathjax_js_url = 'http://cdn.mathjax.org/mathjax/latest/MathJax.js'
 
     mathjax_config_file = getattr(settings, 'MATHJAX_CONFIG_FILE', None)
     url = mathjax_js_url
